==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/ron/db/parameters.php <==
<?php
/**
 * stanislav.elbl, 19.02.2021
 */

namespace Ron\DB;
use Exception;

/**
 * Parametry SQL vyrazu. Slouzi pro vkladani parametru do textu SQL vyrazu a uchovani jejich hodnot.
 * Class Parameters
 * @package Ron\DB
 */
abstract class Parameters
{
    /** @var Database */
    protected $database;


    /**
     * Parameters constructor.
     * @param Database $database
     */
    public function __construct(Database $database)
    {
        $this->database = $database;
    }


    /**
     * Prida parametr do seznamu a vraci text pro vlozeni do SQL dotazu
     * @param mixed $value
     * @return string
     */
    public abstract function addParameter($value);

    /**
     * Prida datumovy parametr
     * @param int $value
     * @return string
     * @throws Exception
     */
    public function addDateParameter($value)
    {
        if (!$this ->database) {
            throw new Exception('Chyba v metode AdHocParameters::addDateParameter - neni nastavena $database!');
        }

        return $this ->addParameter($this ->database ->dateToParam($value));
    }

    /**
     * Prida parametr typu timestamp
     * @param int $value
     * @return string
     * @throws Exception
     */
    public function addTimestampParameter($value)
    {
        if (!$this ->database) {
            throw new Exception('Chyba v metode AdHocParameters::addTimestampParameter - neni nastavena $database!');
        }

        return $this ->addParameter($this ->database ->timestampToParam($value));
    }


    /**
     * @return array
     */
    public abstract function getSqlParameters();

    /**
     * Pripoji dalsi parametry - pouzije se pri spojovani casti SQL dotazu
     * @param Parameters $params
     * @return Parameters   vraci $this
     */
    public abstract function appendParameters($params);

    /**
     * Vytvori novou instanci parametru stejneho typu.
     * @return Parameters
     */
    public abstract function newInstance();

    /**
     * @return string
     */
    public abstract function getLogText();
}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/ron/db/parameters.php <==
<?php
/**
 * stanislav.elbl, 19.02.2021
 */

namespace Ron\DB;
use Exception;

/**
 * Parametry SQL vyrazu. Slouzi pro vkladani parametru do textu SQL vyrazu a uchovani jejich hodnot.
 * Class Parameters
 * @package Ron\DB
 */
abstract class Parameters
{
    /** @var Database */
    protected $database;


    /**
     * Parameters constructor.
     * @param Database $database
     */
    public function __construct(Database $database)
    {
        $this->database = $database;
    }


    /**
     * Prida parametr do seznamu a vraci text pro vlozeni do SQL dotazu
     * @param mixed $value
     * @return string
     */
    public abstract function addParameter($value);

    /**
     * Prida datumovy parametr
     * @param int $value
     * @return string
     * @throws Exception
     */
    public function addDateParameter($value)
    {
        if (!$this ->database) {
            throw new Exception('Chyba v metode AdHocParameters::addDateParameter - neni nastavena $database!');
        }

        return $this ->addParameter($this ->database ->dateToParam($value));
    }

    /**
     * Prida parametr typu timestamp
     * @param int $value
     * @return string
     * @throws Exception
     */
    public function addTimestampParameter($value)
    {
        if (!$this ->database) {
            throw new Exception('Chyba v metode AdHocParameters::addTimestampParameter - neni nastavena $database!');
        }

        return $this ->addParameter($this ->database ->timestampToParam($value));
    }


    /**
     * Vraci parametry, ktere databaze pouzije pri provedeni SQL vyrazu
     * @return array
     */
    public abstract function getSqlParameters();

    /**
     * Pripoji dalsi parametry - pouzije se pri spojovani vice casti SQL dotazu
     * @param Parameters    $params
     * @return Parameters   vraci $this
     */
    public abstract function appendParameters($params);

    /**
     * Vytvori novou instanci parametru stejneho typu.
     * @return Parameters
     */
    public abstract function newInstance();

    /**
     * Vraci text pro zapis do LOGu
     * @return string
     */
    public abstract function getLogText();
}
